##  Clear Overview of Successor
The successor view aims to help you to:
  * Identify Successors Clearly: By displaying successors in a non-collapsible manner, they can be easily distinguished from drill-downs, allowing you to recognize which applications are successors quickly.
  * Understand Succession Timelines: We create more space to enhance your understanding of when each successor is scheduled to occur, providing a clearer view of the timeline.
  * Remove Duplicate Data: To facilitate a quicker comprehension of the data, we eliminate duplicates caused by successors being shown as drill-downs. The list of applications now only includes those with a start date within the timeframe, excluding any that are successors.


To enable the successor view, go to Settings and select the Successor View as shown below.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750fb547a44101487d4a3109a8b9305_LowRes.png)
Once selected, the left-hand side of the Roadmap report will reflect the successor information where it exists.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275071007a441014b74cd2945929b2d8_LowRes.png)
